==================
Climate categories
==================


.. image:: https://img.shields.io/pypi/v/climate_categories.svg
        :target: https://pypi.python.org/pypi/climate_categories

.. image:: https://readthedocs.org/projects/climate-categories/badge/?version=latest
        :target: https://climate-categories.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4590232.svg
        :target: https://doi.org/10.5281/zenodo.4590232

Commonly used codes, categories, terminologies, and nomenclatures used in climate
policy analysis in a nice Python package.
The documentation can be found at: https://climate-categories.readthedocs.io.

Included categorizations
------------------------

==========  ===================================
Name        Title
----------  -----------------------------------
IPCC1996    IPCC GHG emission categories (1996)
IPCC2006    IPCC GHG emission categories (2006)
==========  ===================================

Status
------
Climate categories is still in development and the API and names of categorizations
are still subject to change.

License
-------
Copyright 2021, Potsdam-Institut für Klimafolgenforschung e.V.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this
file except in compliance with the License. You may obtain a copy of the License at

https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under
the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied. See the License for the specific language governing
permissions and limitations under the License.

Citation
--------
If you use this library and want to cite it, please cite it as:

Mika Pflüger, Annika Günther, and Johannes Gütschow. (2021-03-23).
pik-primap/climate_categories: Version 0.5.0.
Zenodo. https://doi.org/10.5281/zenodo.4630667
